@@ -8,7 +8,7 @@ use strict;
 use warnings;
 
 our $AUTHORITY = 'cpan:MAROS';
-our $VERSION = '1.36';
+our $VERSION = 1.37;
 
 use MooseX::App::Meta::Role::Attribute::Option;
 use MooseX::App::Exporter qw(app_usage app_description app_base app_fuzzy app_strict app_prefer_commandline app_permute option parameter);
@@ -87,6 +87,9 @@ sub new_with_command {
         if $metameta->does_role('MooseX::App::Meta::Role::Class::Command')
         || ! $metameta->does_role('MooseX::App::Meta::Role::Class::Base');
 
+    $meta->command_check()
+        if $ENV{APP_DEVELOPER} || $ENV{HARNESS_ACTIVE};
+
     # Extra args
     my %args;
     if (scalar @args == 1
@@ -503,6 +506,8 @@ Options and parameters accept extra attributes for customisation:
 
 =item * cmd_count - Value of option equals to number of occurrences in @ARGV
 
+=item * cmd_negate - Adds an option to negate boolean flags
+
 =back
 
 Refer to L<MooseX::App::Meta::Role::Attribute::Option> for detailed
