@@ -101,6 +101,15 @@ sub _build_app_commands {
     return { @list };
 }
 
+sub command_check {
+    my ($self) = @_;
+
+    foreach my $attribute ($self->command_usage_attributes($self,'all')) {
+        $attribute->cmd_check();
+    }
+    return;
+}
+
 sub command_scan_namespace {
     my ($self,$namespace) = @_;
 
@@ -361,14 +370,19 @@ sub command_parse_options {
         next
             unless exists $match->{$attribute->name};
 
-        my $raw = [
-            map { $_->[0] }
-            sort { $a->[1] <=> $b->[1] }
-            map { @{$_->value} }
-            @{$match->{$attribute->name}}
+        my @mapped_values;
+        foreach my $element (@{$match->{$attribute->name}}) {
+            push(@mapped_values,$element->all_values);
+        }
+
+        my $values = [
+            map { $_->value }
+            sort { $a->position <=> $b->position }
+            @mapped_values
         ];
 
-        my ($value,$errors) = $self->command_process_attribute( $attribute, $raw );
+        #warn Data::Dumper::Dumper($raw);
+        my ($value,$errors) = $self->command_process_attribute( $attribute, $values );
         push(@errors,@{$errors});
 
         $return->{$attribute->name} = $value;
@@ -422,7 +436,7 @@ sub command_process_attribute {
                 }
             }
         } elsif ($type_constraint->is_a_type_of('Bool')) {
-            $value = defined $raw->[-1] ? $raw->[-1] : 1;
+            $value = $raw->[-1];
 
 #            if ($self->has_default
 #                && ! $self->is_default_a_coderef
@@ -538,26 +552,44 @@ sub command_parser_hints {
 
     my %hints;
     my %names;
+    my $return = { permute => [], novalue => [], fixedvalue => {} };
     foreach my $attribute ($self->command_usage_attributes($metaclass,[qw(option proto)])) {
         my $permute = 0;
+        my $bool = 0;
         my $type_constraint = $attribute->type_constraint;
-        if ($type_constraint
-            && (
-                $type_constraint->is_a_type_of('ArrayRef')
-                || $type_constraint->is_a_type_of('HashRef')
-            )) {
-            $permute = 1;
+        if ($type_constraint) {
+            $permute = 1
+                if $type_constraint->is_a_type_of('ArrayRef')
+                || $type_constraint->is_a_type_of('HashRef');
+
+            $bool = 1
+                if $type_constraint->is_a_type_of('Bool');
         }
 
         my $hint = {
             name    => $attribute->name,
-            novalue => ! $attribute->cmd_has_value,
+            bool    => $bool,
+            novalue => $bool || $attribute->cmd_count,
             permute => $permute,
         };
 
-        foreach my $name ($attribute->cmd_name_possible) {
+        foreach my $name ($attribute->cmd_name_list) {
              $names{$name} = $hints{$name} = $hint;
         }
+
+        # Negated values
+        if ($bool) {
+            $hint->{fixedvalue} = 1;
+            if ($attribute->has_cmd_negate) {
+                my $hint_neg = { %{$hint} }; # shallow copy
+                $hint_neg->{fixedvalue} = 0;
+                foreach my $name (@{$attribute->cmd_negate}) {
+                    $names{$name} = $hints{$name} = $hint_neg;
+                }
+            }
+        } elsif ($attribute->cmd_count) {
+            $hint->{fixedvalue} = 1;
+        }
     }
 
     if ($self->app_fuzzy) {
@@ -584,7 +616,6 @@ sub command_parser_hints {
         }
     }
 
-    my $return = { permute => [], novalue => [] };
     foreach my $name (keys %hints) {
         if ($hints{$name}->{novalue}) {
             push(@{$return->{novalue}},$name);
@@ -592,7 +623,13 @@ sub command_parser_hints {
         if ($hints{$name}->{permute}) {
             push(@{$return->{permute}},$name);
         }
+        if (defined $hints{$name}->{fixedvalue}) {
+            $return->{fixedvalue}{$name} = $hints{$name}->{fixedvalue};
+        }
     }
+
+
+        #warn Data::Dumper::Dumper($return);
     return $return;
 }
 
@@ -900,6 +937,11 @@ Boolean flag that controls if command line arguments that take multiple values
 
 =head1 METHODS
 
+=head2 command_check
+
+Runs sanity checks on options and parameters. Will usually only be executed if
+either HARNESS_ACTIVE or APP_DEVELOPER environment are set.
+
 =head2 command_register
 
  $self->command_register($command_moniker,$command_class);
